Markov Chains
--------------

*transition_matrix()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.markov.transition_matrix

*markov_simulate()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.markov.markov_simulate

*markov_test_random()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.markov.markov_test_random

*markov_test_symmetry()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.markov.markov_test_symmetry

*markov_test_homogeneity()*
""""""""""""""""""""""""""""
.. autofunction:: neurokit2.markov.markov_test_homogeneity

*markov_mixingtime()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.markov.markov_mixingtime